PENGEOM
=======

Base classes
------------

.. automodule:: pypenelopetools.pengeom.base
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
    
.. automodule:: pypenelopetools.pengeom.mixin
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pypenelopetools.pengeom.transformation
    :members:
    :undoc-members:
    :show-inheritance:

Geometry
--------

.. automodule:: pypenelopetools.pengeom.geometry
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

Surfaces
--------

.. automodule:: pypenelopetools.pengeom.surface
    :members:
    :inherited-members:
    :show-inheritance:
    
Module
------

.. automodule:: pypenelopetools.pengeom.module
    :members:
    :show-inheritance: